@@ -231,11 +231,11 @@ class Repository:
             if type(value) is str:
                 value = f"'{value}'"
             elif type(value) is date:
-                value = f"'{datetime.strftime(value, '%Y-%M-%d')}'"
+                value = f"'{datetime.strftime(value, '%Y-%m-%d')}'"
             elif type(value) is time:
-                value = f"'{datetime.strftime(value, '%H-%m-%s')}'"
+                value = f"'{datetime.strftime(value, '%H-%M-%S')}'"
             elif type(value) is datetime:
-                value = f"'{datetime.strftime(value, '%Y-%M-%d %H-%m-%s')}'"
+                value = f"'{datetime.strftime(value, '%Y-%m-%d %H-%M-%S')}'"
 
             query_string = query_string.replace(f':{param}', str(value))
 
