@@ -23,7 +23,7 @@ import base64
 
 class Selenium(Scraper):
 
-    def __init__(self, config: Config, headless: bool=True, window: dict={}, user_dir: str=None):
+    def __init__(self, config: Config, headless: bool=True, window: dict={}, user_dir: str=None, disable_javascript: bool=False):
         
         url = config.get(section='SELENIUM', key='url')
 
@@ -38,6 +38,9 @@ class Selenium(Scraper):
             options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
 
         #region options
+        if disable_javascript is True:
+            options.add_experimental_option('prefs', { 'profile.managed_default_content_settings.javascript': 2 })
+
         options.add_argument('--no-sandbox')
         options.add_argument('--log-level=3')        
         options.add_argument('--disable-extensions')
@@ -100,7 +103,8 @@ class Selenium(Scraper):
 
         if timeout > 0:
             try:
-                return WebDriverWait(element, timeout).until(
+                ignored_exceptions = (NoSuchElementException, StaleElementReferenceException)
+                return WebDriverWait(driver=element, timeout=timeout, ignored_exceptions=ignored_exceptions).until(
                     EC.presence_of_element_located((By.XPATH, path))
                 )
             except Exception as e:
